@@ -102,20 +102,20 @@ def dulwich_commit_to_revision(commit, log=None) -> Revision:
     if commit.type_name != b"commit":
         raise ValueError("Argument is not a commit.")
 
-    git_metadata = []
+    extra_headers = []
     if commit.encoding is not None:
-        git_metadata.append((b"encoding", commit.encoding))
+        extra_headers.append((b"encoding", commit.encoding))
     if commit.mergetag:
         for mergetag in commit.mergetag:
             raw_string = mergetag.as_raw_string()
             assert raw_string.endswith(b"\n")
-            git_metadata.append((b"mergetag", raw_string[:-1]))
+            extra_headers.append((b"mergetag", raw_string[:-1]))
 
     if commit.extra:
-        git_metadata.extend((k, v) for k, v in commit.extra)
+        extra_headers.extend((k, v) for k, v in commit.extra)
 
     if commit.gpgsig:
-        git_metadata.append((b"gpgsig", commit.gpgsig))
+        extra_headers.append((b"gpgsig", commit.gpgsig))
 
     return Revision(
         id=commit.sha().digest(),
@@ -131,7 +131,7 @@ def dulwich_commit_to_revision(commit, log=None) -> Revision:
         directory=bytes.fromhex(commit.tree.decode()),
         message=commit.message,
         metadata=None,
-        extra_headers=tuple(git_metadata),
+        extra_headers=tuple(extra_headers),
         synthetic=False,
         parents=tuple(bytes.fromhex(p.decode()) for p in commit.parents),
     )
